| Title: | Refined Modified Stahel-Donoho Estimators for Outlier Detection |
|---|---|
| Description: | A function for multivariate outlier detection named Modified Stahel-Donoho (MSD) estimators is contained. The function is for elliptically distributed datasets and recognizes outliers based on Mahalanobis distance. The function is called the single core version in Wada & Tsubaki (2013) <doi:10.1109/CLOUDCOM-ASIA.2013.86> and evaluated with other methods in Wada, Kawano & Tsubaki (2020) <doi:10.17713/ajs.v49i2.872>. |
| Authors: | Kazumi Wada [aut, cre] (ORCID: <https://orcid.org/0000-0002-9578-1588>) |
| Maintainer: | Kazumi Wada <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.1 |
| Built: | 2026-05-18 08:46:39 UTC |
| Source: | https://github.com/kazwd2008/rmsd |
This function is for multivariate outlier detection. Ver.1.6 2009/07/14 Published at http://www.stat.go.jp/training/2kenkyu/pdf/ihou/67/wada1.pdf (in Japanese) Ver.1.7 2018/10/19 Modify gso function to stop warning messages Ver.2 2021/09/10 Added the outlier detection step
RMSD(inp, nb = 0, sd = 0, pt = 0.999)RMSD(inp, nb = 0, sd = 0, pt = 0.999)
inp |
input data (a numeric matrix) |
nb |
number of basis |
sd |
seed (for reproducibility) |
pt |
threshold for outlier detection (probability) |
a list of the following information
u final mean vector
V final covariance matrix
wt final weights
mah squared Mahalanobis distance of each observation
FF F test statistics
cf threshold to detect outliers (percentile point)
ot outlier flag (1:normal observation, 2:outlier)